@@ -12,8 +12,6 @@ use parent (
 
 use constant _DEFERRED_CR => \&Promise::XS::deferred;
 
-*_dns_unbound_then = \&Promise::XS::Promise::then;
-
-*_dns_unbound_finally = \&Promise::XS::Promise::finally;
+*_then = \&Promise::XS::Promise::then;
 
 1;
